%{?mingw_package_header}

%global pkgname qwt

%bcond_without qt5
%bcond_without qt6

Name:           mingw-%{pkgname}
Summary:        MinGW Windows Qwt library
Version:        6.2.0
Release:        7%{?dist}
URL:            http://qwt.sourceforge.net
License:        LGPL-2.0-or-later WITH FLTK-exception
BuildArch:      noarch
Source:         http://downloads.sourceforge.net/%{pkgname}/%{pkgname}-%{version}.tar.bz2
# Use QT_INSTALL_ paths instead of custom prefix
Patch51:        qwt-qt_install_paths.patch
# Add qt suffix to libraries to make them parallel-installable
Patch52:        qwt-libsuffix.patch
# Kill rpath
Patch53:        qwt-no_rpath.patch
# Fix incorrect requires in pkgconfig files
Patch54:        qwt-pkgconfig.patch

BuildRequires:  make
BuildRequires:  mingw32-filesystem
BuildRequires:  mingw32-gcc-c++
BuildRequires:  mingw64-filesystem
BuildRequires:  mingw64-gcc-c++

%description
MinGW Windows Qwt library.


%if %{with qt5}
%package -n mingw32-%{pkgname}-qt5
Summary:        MinGW Windows Qwt library
BuildRequires:  mingw32-qt5-qtbase-devel
BuildRequires:  mingw32-qt5-qtsvg
BuildRequires:  mingw32-qt5-qttools

%description -n mingw32-%{pkgname}-qt5
MinGW Windows Qwt library.

%package -n mingw64-%{pkgname}-qt5
Summary:        MinGW Windows Qwt library
BuildRequires:  mingw64-qt5-qtbase-devel
BuildRequires:  mingw64-qt5-qtsvg
BuildRequires:  mingw64-qt5-qttools

%description -n mingw64-%{pkgname}-qt5
MinGW Windows Qwt library.
%endif

%if %{with qt6}
%package -n mingw32-%{pkgname}-qt6
Summary:        MinGW Windows Qwt library
BuildRequires:  mingw32-qt6-qtbase
BuildRequires:  mingw32-qt6-qtsvg
BuildRequires:  mingw32-qt6-qttools

%description -n mingw32-%{pkgname}-qt6
MinGW Windows Qwt library.

%package -n mingw64-%{pkgname}-qt6
Summary:        MinGW Windows Qwt library
BuildRequires:  mingw64-qt6-qtbase
BuildRequires:  mingw64-qt6-qtsvg
BuildRequires:  mingw64-qt6-qttools

%description -n mingw64-%{pkgname}-qt6
MinGW Windows Qwt library.
%endif


%{?mingw_debug_package}

%prep
%autosetup -p1 -n %{pkgname}-%{version}
# Adjust config

sed -Ei 's|QWT_CONFIG\s*\+= QwtExamples|#QWT_CONFIG += QwtExamples|' qwtconfig.pri
sed -Ei 's|QWT_CONFIG\s*\+= QwtPlayground|#QWT_CONFIG += QwtPlayground|' qwtconfig.pri
sed -Ei 's|QWT_CONFIG\s*\+= QwtTests|#QWT_CONFIG += QwtTests|' qwtconfig.pri
sed -Ei 's|QWT_CONFIG\s*\+= QwtDesigner|#QWT_CONFIG += QwtDesigner|' qwtconfig.pri

%build

%if %{with qt5}
export MINGW_BUILDDIR_SUFFIX=qt5
%{mingw_qmake_qt5} QWT_CONFIG+=QwtPkgConfig ..
%mingw_make_build
%endif

%if %{with qt6}
export MINGW_BUILDDIR_SUFFIX=qt6
# /usr/i686-w64-mingw32/sys-root/mingw/include/qt6/QtCore/qconfig.h has
# QT_COMPILER_SUPPORTS_F16C set to 1, also SSE2/3 AVX/2, which seems
# dubious. Hack below makes it compile
echo QMAKE_CXXFLAGS += -msse2 >> qwtbuild.pri
%{mingw_qmake_qt6} QWT_CONFIG+=QwtPkgConfig ..
%mingw_make_build
%endif


%install
%if %{with qt5}
export MINGW_BUILDDIR_SUFFIX=qt5
%mingw_make_install INSTALL_ROOT=%{buildroot}
%endif
%if %{with qt6}
# FIXME Fix incorrect install command generated by qmake
sed -i 's|../build_win32qt6/lib/pkgconfig/Qt6Qwt6.pc|../lib/pkgconfig/Qt6Qwt6.pc|' build_win32qt6/src/Makefile.{Debug,Release}
sed -i 's|../build_win64qt6/lib/pkgconfig/Qt6Qwt6.pc|../lib/pkgconfig/Qt6Qwt6.pc|' build_win64qt6/src/Makefile.{Debug,Release}
export MINGW_BUILDDIR_SUFFIX=qt6
%mingw_make_install INSTALL_ROOT=%{buildroot}
%endif

# Delete docs
rm -rf %{buildroot}%{mingw32_prefix}/doc
rm -rf %{buildroot}%{mingw64_prefix}/doc
rm -rf %{buildroot}%{mingw32_docdir}
rm -rf %{buildroot}%{mingw64_docdir}

# Delete debug libs
rm -f %{buildroot}%{mingw32_libdir}/qwt-qt{5,6}d.dll
rm -f %{buildroot}%{mingw64_libdir}/qwt-qt{5,6}d.dll
rm -f %{buildroot}%{mingw32_libdir}/libqwt-qt5d.dll.a
rm -f %{buildroot}%{mingw64_libdir}/libqwt-qt5d.dll.a
rm -f %{buildroot}%{mingw32_libdir}/libqwt-qt6d.a
rm -f %{buildroot}%{mingw64_libdir}/libqwt-qt6d.a
rm -f %{buildroot}%{mingw32_libdir}/pkgconfig/Qt5Qwt6d.pc
rm -f %{buildroot}%{mingw64_libdir}/pkgconfig/Qt5Qwt6d.pc

# Fix import lib file extension
mv %{buildroot}%{mingw32_libdir}/libqwt-qt6.a %{buildroot}%{mingw32_libdir}/libqwt-qt6.dll.a
mv %{buildroot}%{mingw64_libdir}/libqwt-qt6.a %{buildroot}%{mingw64_libdir}/libqwt-qt6.dll.a

# Move binaries to correct location
mkdir -p %{buildroot}%{mingw32_bindir}
mkdir -p %{buildroot}%{mingw64_bindir}
mv %{buildroot}%{mingw32_libdir}/*.dll %{buildroot}%{mingw32_bindir}
mv %{buildroot}%{mingw64_libdir}/*.dll %{buildroot}%{mingw64_bindir}


%if %{with qt5}
%files -n mingw32-%{pkgname}-qt5
%license COPYING
%{mingw32_bindir}/%{pkgname}-qt5.dll
%{mingw32_libdir}/lib%{pkgname}-qt5.dll.a
%{mingw32_includedir}/qt5/%{pkgname}/
%{mingw32_datadir}/qt5/mkspecs/features/qwt*
%{mingw32_libdir}/pkgconfig/Qt5Qwt6.pc

%files -n mingw64-%{pkgname}-qt5
%license COPYING
%{mingw64_bindir}/%{pkgname}-qt5.dll
%{mingw64_libdir}/lib%{pkgname}-qt5.dll.a
%{mingw64_includedir}/qt5/%{pkgname}/
%{mingw64_datadir}/qt5/mkspecs/features/qwt*
%{mingw64_libdir}/pkgconfig/Qt5Qwt6.pc
%endif

%if %{with qt6}
%files -n mingw32-%{pkgname}-qt6
%license COPYING
%{mingw32_bindir}/%{pkgname}-qt6.dll
%{mingw32_libdir}/lib%{pkgname}-qt6.dll.a
%{mingw32_includedir}/qt6/%{pkgname}/
%{mingw32_libdir}/qt6/mkspecs/features/qwt*
%{mingw32_libdir}/pkgconfig/Qt6Qwt6.pc

%files -n mingw64-%{pkgname}-qt6
%license COPYING
%{mingw64_bindir}/%{pkgname}-qt6.dll
%{mingw64_libdir}/lib%{pkgname}-qt6.dll.a
%{mingw64_includedir}/qt6/%{pkgname}/
%{mingw64_libdir}/qt6/mkspecs/features/qwt*
%{mingw64_libdir}/pkgconfig/Qt6Qwt6.pc
%endif

%changelog
* Fri Jan 17 2025 Fedora Release Engineering <releng@fedoraproject.org> - 6.2.0-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_42_Mass_Rebuild

* Thu Jul 18 2024 Fedora Release Engineering <releng@fedoraproject.org> - 6.2.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_41_Mass_Rebuild

* Thu Jan 25 2024 Fedora Release Engineering <releng@fedoraproject.org> - 6.2.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Sun Jan 21 2024 Fedora Release Engineering <releng@fedoraproject.org> - 6.2.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Thu Jul 20 2023 Fedora Release Engineering <releng@fedoraproject.org> - 6.2.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Thu Jan 19 2023 Fedora Release Engineering <releng@fedoraproject.org> - 6.2.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Thu Dec 29 2022 Sandro Mani <manisandro@gmail.com> - 6.2.0-1
- Update to 6.2.0

* Thu Oct 20 2022 Sandro Mani <manisandro@gmail.com> - 6.1.5-6
- Fix missing version field in pkgconfig file

* Thu Jul 21 2022 Fedora Release Engineering <releng@fedoraproject.org> - 6.1.5-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Fri Mar 25 2022 Sandro Mani <manisandro@gmail.com> - 6.1.5-4
- Rebuild with mingw-gcc-12

* Thu Jan 20 2022 Fedora Release Engineering <releng@fedoraproject.org> - 6.1.5-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Thu Jul 22 2021 Fedora Release Engineering <releng@fedoraproject.org> - 6.1.5-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Mon Feb 01 2021 Thomas Sailer <t.sailer@alumni.ethz.ch> - 6.1.5-1
- update to 6.1.5

* Tue Jul 28 2020 Fedora Release Engineering <releng@fedoraproject.org> - 6.1.3-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Wed Jan 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 6.1.3-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Tue Oct 08 2019 Sandro Mani <manisandro@gmail.com> - 6.1.3-8
- Rebuild (Changes/Mingw32GccDwarf2)
- Drop Qt4 build

* Thu Jul 25 2019 Fedora Release Engineering <releng@fedoraproject.org> - 6.1.3-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Fri Feb 01 2019 Fedora Release Engineering <releng@fedoraproject.org> - 6.1.3-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 6.1.3-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Thu Jul 12 2018 Richard W.M. Jones <rjones@redhat.com> - 6.1.3-4
- Remove buildroot.

* Mon May 28 2018 Thomas Sailer <t.sailer@alumni.ethz.ch> - 6.1.3-3
- fix build failure

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 6.1.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Fri May 05 2017 Thomas Sailer <t.sailer@alumni.ethz.ch> - 6.1.3-1
- update to 6.1.3

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 6.1.2-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 6.1.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 6.1.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Fri Jan 02 2015 Thomas Sailer <t.sailer@alumni.ethz.ch> - 6.1.2-2
- enable qt5 build

* Fri Jan 02 2015 Thomas Sailer <t.sailer@alumni.ethz.ch> - 6.1.2-1
- update to 6.1.2

* Wed Nov 05 2014 Thomas Sailer <t.sailer@alumni.ethz.ch> - 6.1.1-1
- update to 6.1.1

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 6.1.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Tue Dec  3 2013 Thomas Sailer <t.sailer@alumni.ethz.ch> - 6.1.0-1
- update to 6.1.0

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 6.0.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Sun Jan 27 2013 Erik van Pienbroek <epienbro@fedoraproject.org> - 6.0.1-2
- Rebuild against mingw-gcc 4.8 (win64 uses SEH exceptions now)

* Tue Dec  4 2012 Thomas Sailer <t.sailer@alumni.ethz.ch> - 6.0.1-1
- update to 6.0.1

* Fri Jul 20 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 5.2.1-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Fri Mar 09 2012 Erik van Pienbroek <epienbro@fedoraproject.org> - 5.2.1-7
- Use the correct qmake macros to build this package

* Wed Mar 07 2012 Kalev Lember <kalevlember@gmail.com> - 5.2.1-6
- Renamed the source package to mingw-qwt (#801020)
- Modernize the spec file
- Use mingw macros without leading underscore

* Tue Feb 28 2012 Erik van Pienbroek <epienbro@fedoraproject.org> - 5.2.1-5
- Rebuild against the mingw-w64 toolchain

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 5.2.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Fri Apr 22 2011 Kalev Lember <kalev@smartlink.ee> - 5.2.1-3
- Rebuilt for pseudo-reloc version mismatch (#698827)

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 5.2.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Fri Apr 23 2010 Thomas Sailer <t.sailer@alumni.ethz.ch> - 5.2.1-1
- update to 5.2.1

* Sat Feb 13 2010 Thomas Sailer <t.sailer@alumni.ethz.ch> - 5.2.0-3
- qt 4.6.1 compile workaround

* Wed Dec  2 2009 Thomas Sailer <t.sailer@alumni.ethz.ch> - 5.2.0-2
- qt 4.6.0 compile workarounds

* Tue Nov 24 2009 Thomas Sailer <t.sailer@alumni.ethz.ch> - 5.2.0-1
- update to 5.2.0

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 5.1.1-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Mon Jun 22 2009 Thomas Sailer <t.sailer@alumni.ethz.ch> - 5.1.1-8
- add debuginfo packages

* Thu Apr 16 2009 Thomas Sailer <t.sailer@alumni.ethz.ch> - 5.1.1-7
- replace %%define with %%global

* Mon Mar 16 2009 Thomas Sailer <t.sailer@alumni.ethz.ch> - 5.1.1-6
- actually fix the source line as required by the reviewer
- remove commented out designer files in files section

* Mon Mar 16 2009 Thomas Sailer <t.sailer@alumni.ethz.ch> - 5.1.1-5
- fix missing BR

* Fri Mar 13 2009 Thomas Sailer <t.sailer@alumni.ethz.ch> - 5.1.1-4
- enable debug build

* Wed Mar 11 2009 Thomas Sailer <t.sailer@alumni.ethz.ch> - 5.1.1-3
- copied from native qwt
